'''
Copyright (C) 2024 1P2D
https://1p2d.com
me@1p2d.com

Created by 1P2D - Felix Pierron

This file is part of the HDRI Rotator.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see <https://www.gnu.org/licenses>.
'''

bl_info = {
    "name": "HDRI Rotator",
    "description": "Rotate your HDRI/shadows from the viewport (CTRL+ALT+RMB).",
    "author": "1P2D <me@1p2d.com>",
    "version": (1, 0, 2),
    "blender": (4, 2, 0),
    "category": "Lighting",
    "location": "3D View",
    "doc_url": "https://www.1p2d.com/rotate-your-hdri-in-one-click",
    "tracker_url": "https://discord.com/channels/1292293905097822260/1292294042712932447"
    }


from . import operators, preferences
import bpy

def register():
    operators.register()
    preferences.register()
    register_keymaps()

def register_keymaps():
    # Import the operator class
    from .operators import HDRI_Rotator

    # Set up keymap for ALT + LMB in the 3D View
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon
    if kc:
        km = kc.keymaps.new(name='3D View', space_type='VIEW_3D')
        kmi = km.keymap_items.new(HDRI_Rotator.bl_idname, 'RIGHTMOUSE', 'PRESS', alt=True, ctrl=True)
        kmi.active = True

def unregister_keymaps():
    # Import the operator class
    from .operators import HDRI_Rotator
    
    # Remove keymap
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon
    if kc:
        km = kc.keymaps.get('3D View')
        if km:
            for kmi in km.keymap_items:
                if kmi.idname == HDRI_Rotator.bl_idname:
                    km.keymap_items.remove(kmi)
                    break

def unregister():
    unregister_keymaps()
    operators.unregister()
    preferences.unregister()

if __name__ == "__main__":
    register()

